@@ -11,6 +11,7 @@ from scipy.stats import randint,uniform
 from xgboost import XGBClassifier, XGBRegressor
 #from catboost import CatBoostClassifier, CatBoostRegressor
 from lightgbm import LGBMClassifier, LGBMRegressor
+from skrvm import RVR, RVC
 import numpy as np
 #from bartpy.sklearnmodel import SklearnModel
 #from bartpy.extensions.baseestimator import ResidualBART
@@ -213,6 +214,32 @@ class ML():
                           },
                 'RSCV'  : {}
                 }},
+        'RVMrbf'        : {
+            'estimator' : RVC(kernel='rbf'),
+            'parameters': {
+                'GSCV'  : { 'n_iter': [100, 300, 500, 1000, 2000, 3000, 5000],
+                            'tol': [ 1e-7, 1e-6, 1e-5, 1e-4, 1e-3, 1e-2, 1e-1 ],
+                            'alpha': [1e1, 1e0, 1e-1, 1e-2, 1e-3, 1e-4, 1e-5, 1e-6],
+                            'threshold_alpha': [1e2, 1e3, 1e5, 1e7, 1e8, 1e9],
+                            'beta': [1e1, 1e0, 1e-1, 1e-2, 1e-3, 1e-4, 1e-5, 1e-6],
+                            'beta_fixed': [False, True],
+                            'bias_used': [False, True]
+                          },
+                'RSCV'  : {}
+                }},
+        'RVMpoly'        : {
+            'estimator' : RVC(kernel='poly'),
+            'parameters': {
+                'GSCV'  : { 'n_iter': [100, 300, 500, 1000, 2000, 3000, 5000],
+                            'tol': [ 1e-7, 1e-6, 1e-5, 1e-4, 1e-3, 1e-2, 1e-1 ],
+                            'alpha': [1e1, 1e0, 1e-1, 1e-2, 1e-3, 1e-4, 1e-5, 1e-6],
+                            'threshold_alpha': [1e2, 1e3, 1e5, 1e7, 1e8, 1e9],
+                            'beta': [1e1, 1e0, 1e-1, 1e-2, 1e-3, 1e-4, 1e-5, 1e-6],
+                            'beta_fixed': [False, True],
+                            'bias_used': [False, True]
+                          },
+                'RSCV'  : {}
+                }},
         'SVM'           : {
             'estimator' : SVC(probability=True, decision_function_shape='ovr', random_state=123456),
             'parameters': {
